@@ -222,13 +222,13 @@ class CfnEnvironmentEC2(
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''The Amazon Resource Name (ARN) of the development environment, such as ``arn:aws:cloud9:us-east-2:123456789012:environment:2bc3642873c342e485f7e0c561234567`` .
@@ -237,7 +237,7 @@ class CfnEnvironmentEC2(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> builtins.str:
         '''The name of the environment.
@@ -246,12 +246,12 @@ class CfnEnvironmentEC2(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> aws_cdk.core.TagManager:
         '''An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
@@ -260,7 +260,7 @@ class CfnEnvironmentEC2(
         '''
         return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="instanceType")
     def instance_type(self) -> builtins.str:
         '''The type of instance to connect to the environment (for example, ``t2.micro`` ).
@@ -276,7 +276,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="automaticStopTimeMinutes")
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
         '''The number of minutes until the running instance is shut down after the environment was last used.
@@ -292,7 +292,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "automaticStopTimeMinutes", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connectionType")
     def connection_type(self) -> typing.Optional[builtins.str]:
         '''The connection type used for connecting to an Amazon EC2 environment.
@@ -310,7 +310,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
         '''The description of the environment to create.
@@ -326,7 +326,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="imageId")
     def image_id(self) -> typing.Optional[builtins.str]:
         '''The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance.
@@ -358,7 +358,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Optional[builtins.str]:
         '''The name of the environment.
@@ -374,7 +374,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ownerArn")
     def owner_arn(self) -> typing.Optional[builtins.str]:
         '''The Amazon Resource Name (ARN) of the environment owner.
@@ -392,7 +392,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ownerArn", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositories")
     def repositories(
         self,
@@ -413,7 +413,7 @@ class CfnEnvironmentEC2(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositories", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnetId")
     def subnet_id(self) -> typing.Optional[builtins.str]:
         '''The ID of the subnet in Amazon Virtual Private Cloud (Amazon VPC) that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
@@ -774,7 +774,7 @@ class CloneRepository(
         )
     '''
 
-    @jsii.member(jsii_name="fromCodeCommit") # type: ignore[misc]
+    @jsii.member(jsii_name="fromCodeCommit")
     @builtins.classmethod
     def from_code_commit(
         cls,
@@ -794,7 +794,7 @@ class CloneRepository(
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("CloneRepository", jsii.sinvoke(cls, "fromCodeCommit", [repository, path]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="pathComponent")
     def path_component(self) -> builtins.str:
         '''
@@ -802,7 +802,7 @@ class CloneRepository(
         '''
         return typing.cast(builtins.str, jsii.get(self, "pathComponent"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryUrl")
     def repository_url(self) -> builtins.str:
         '''
@@ -893,7 +893,7 @@ class Ec2EnvironmentProps:
             CfnOutput(self, "URL", value=c9env.ide_url)
         '''
         if isinstance(subnet_selection, dict):
-            subnet_selection = aws_cdk.aws_ec2.SubnetSelection(**subnet_selection)
+            subnet_selection = SubnetSelection(**subnet_selection)
         if __debug__:
             type_hints = typing.get_type_hints(Ec2EnvironmentProps.__init__)
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
@@ -1016,7 +1016,7 @@ class IEc2Environment(aws_cdk.core.IResource, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
         '''(experimental) The arn of the EnvironmentEc2.
@@ -1026,7 +1026,7 @@ class IEc2Environment(aws_cdk.core.IResource, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
         '''(experimental) The name of the EnvironmentEc2.
@@ -1038,7 +1038,7 @@ class IEc2Environment(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IEc2EnvironmentProxy(
-    jsii.proxy_for(aws_cdk.core.IResource) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
 ):
     '''(experimental) A Cloud9 Environment.
 
@@ -1047,7 +1047,7 @@ class _IEc2EnvironmentProxy(
 
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-cloud9.IEc2Environment"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
         '''(experimental) The arn of the EnvironmentEc2.
@@ -1057,7 +1057,7 @@ class _IEc2EnvironmentProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ec2EnvironmentArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
         '''(experimental) The name of the EnvironmentEc2.
@@ -1080,8 +1080,8 @@ class Ec2Environment(
     '''(experimental) A Cloud9 Environment with Amazon EC2.
 
     :stability: experimental
-    :exampleMetadata: infused
     :resource: AWS::Cloud9::EnvironmentEC2
+    :exampleMetadata: infused
 
     Example::
 
@@ -1150,7 +1150,7 @@ class Ec2Environment(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromEc2EnvironmentName") # type: ignore[misc]
+    @jsii.member(jsii_name="fromEc2EnvironmentName")
     @builtins.classmethod
     def from_ec2_environment_name(
         cls,
@@ -1173,7 +1173,7 @@ class Ec2Environment(
             check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
         return typing.cast(IEc2Environment, jsii.sinvoke(cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
         '''(experimental) The environment ARN of this Cloud9 environment.
@@ -1183,7 +1183,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ec2EnvironmentArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
         '''(experimental) The environment name of this Cloud9 environment.
@@ -1193,7 +1193,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ec2EnvironmentName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="environmentId")
     def environment_id(self) -> builtins.str:
         '''(experimental) The environment ID of this Cloud9 environment.
@@ -1202,7 +1202,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "environmentId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ideUrl")
     def ide_url(self) -> builtins.str:
         '''(experimental) The complete IDE URL of this Cloud9 environment.
@@ -1211,7 +1211,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ideUrl"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         '''(experimental) VPC ID.
